@@ -152,7 +152,7 @@ def _goes_file_df(satellite, product, start, end, bands=None, refresh=True):
 
     # Todo: this could use some clean up !
     if product.startswith("ABI"):
-        product_mode = df.product_mode.str.rsplit("-", 1, expand=True)
+        product_mode = df.product_mode.str.rsplit("-", n=1, expand=True)
         df["product"] = product_mode[0]
         df["mode_bands"] = product_mode[1]
 
@@ -228,14 +228,15 @@ def _as_xarray_MP(src, save_dir, i=None, n=None, verbose=True):
                 f"\r📖💽 Reading ({i:,}/{n:,}) file from LOCAL COPY [{local_copy}].",
                 end=" ",
             )
-        ds = xr.open_dataset(local_copy)
+        with open(local_copy, "rb") as f:
+            ds = xr.load_dataset(f)
     else:
         if verbose:
             print(
                 f"\r📖☁ Reading ({i:,}/{n:,}) file from AWS to MEMORY [{src}].", end=" "
             )
         with fs.open(src, "rb") as f:
-            ds = xr.open_dataset(f).copy(deep=True)
+            ds = xr.load_dataset(f)
 
     # Turn some attributes to coordinates so they will be preserved
     # when we concat multiple GOES DataSets together.
@@ -610,7 +611,7 @@ def goes_nearesttime(
     df = df.sort_values("start")
     df = df.set_index(df.start)
     unique_times_index = df.index.unique()
-    nearest_time_index = unique_times_index.get_indexer([attime], method='nearest')
+    nearest_time_index = unique_times_index.get_indexer([attime], method="nearest")
     nearest_time = unique_times_index[nearest_time_index]
     df = df.loc[nearest_time]
     df = df.reset_index(drop=True)
